@@ -34,7 +34,7 @@ from .yocto import (
     process_and_upload_yocto_symbols,
 )
 
-LOG = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 pass_memfault_cli_context = click.make_pass_decorator(MemfaultCliClickContext, ensure=True)
@@ -58,8 +58,8 @@ click_option_revision = click.option(
 )
 @click.option("--project-key", help="Memfault Project Key")
 @click.option("--org-token", help="Organization Auth Token")
-@click.option("--org", help="Organization slug")
-@click.option("--project", help="Project slug")
+@click.option("--org", help="Organization slug", callback=MemfaultCliClickContext.validate_slug_arg)
+@click.option("--project", help="Project slug", callback=MemfaultCliClickContext.validate_slug_arg)
 @click.option("--url", hidden=True)
 @click.option("--verbose", help="Log verbosely", is_flag=True)
 @click.version_option(version=version)
