@@ -30,7 +30,7 @@ from .context import DeltaReleaseVersion, MemfaultCliClickContext, PackageInfo
 from .elf import elf_has_debug_info, get_gnu_build_id, is_elf
 from .functools_ext import cached_property
 
-LOG = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 GNU_BUILD_ID_RE = re.compile(r"Build ID: (?P<gnu_build_id>[a-f\d]+)")
 
@@ -124,12 +124,10 @@ class Uploader(metaclass=abc.ABCMeta):
     @abstractmethod
     def can_upload_file(self) -> bool:
         """Test the file pointed to by `file_path`."""
-        pass
 
     @abstractmethod
     def entity_url(self) -> str:
         """The final URL to POST to during the prepared upload sequence."""
-        pass
 
     def ui_url(self) -> Optional[str]:
         """The UI URL at which results from the operation can be seen"""
@@ -175,7 +173,7 @@ class Uploader(metaclass=abc.ABCMeta):
         )
         # This file had already uploaded (maybe concurrently). Gracefully ignore the error then.
         if response.status_code == 409:
-            LOG.info("%s: was already uploaded.", self.file_path)
+            log.info("%s: was already uploaded.", self.file_path)
             return
 
         check_response(response)
@@ -191,12 +189,12 @@ class Uploader(metaclass=abc.ABCMeta):
 
     def upload(self, *, progressbar=True) -> bool:
         if self._is_already_uploaded():
-            LOG.info("%s: skipping, already uploaded.", self.file_path)
+            log.info("%s: skipping, already uploaded.", self.file_path)
             return False
         upload_url, token = self._prepare_upload()
         self._put_file(upload_url, progressbar=progressbar)
         self._post_token(token)
-        LOG.info("%s: uploaded!", self.file_path)
+        log.info("%s: uploaded!", self.file_path)
         if self.ui_url():
             click.echo(f"You can view in the UI here:\n   {self.ui_url()}")
         return True
@@ -220,7 +218,7 @@ class BugreportUploader(Uploader):
 
     def can_upload_file(self) -> bool:
         if not is_zipfile(self.file_path):
-            LOG.error("%s is not a valid zip file!", self.file_path)
+            log.error("%s is not a valid zip file!", self.file_path)
             return False
         return True
 
@@ -242,7 +240,7 @@ class CoredumpUploader(Uploader):
         with open(self.file_path, "rb") as f:
             hdr = f.read(4).decode("ascii", errors="ignore")
             if hdr != "CORE":
-                LOG.error("%s is not a Memfault Coredump", self.file_path)
+                log.error("%s is not a Memfault Coredump", self.file_path)
                 return False
 
         return True
@@ -297,7 +295,7 @@ class MarUploader(Uploader):
 
     def can_upload_file(self) -> bool:
         if not is_zipfile(self.file_path):
-            LOG.error("%s is not a valid zip file!", self.file_path)
+            log.error("%s is not a valid zip file!", self.file_path)
             return False
         return True
 
@@ -364,22 +362,22 @@ class ElfSymbolUploader(Uploader):
 
         with open(self.file_path, "rb") as f:
             if not is_elf(f):
-                LOG.info("%s: Not an ELF file", self.file_path)
+                log.info("%s: Not an ELF file", self.file_path)
                 return False
 
             elf = ELFFile(f)
             gnu_build_id, has_debug_info = get_gnu_build_id(elf), elf_has_debug_info(elf)
             if not gnu_build_id:
-                LOG.info(
+                log.info(
                     "%s: looks like an ELF but does not contain a GNU Build ID", self.file_path
                 )
                 return False
 
         self.gnu_build_id = gnu_build_id
         if not has_debug_info:
-            LOG.info("%s: looks like an ELF but it has no .debug_info", self.file_path)
+            log.info("%s: looks like an ELF but it has no .debug_info", self.file_path)
             return False
-        LOG.info(
+        log.info(
             "%s: ELF file with .debug_info and GNU Build ID: %s", self.file_path, self.gnu_build_id
         )
         return True
@@ -410,13 +408,13 @@ class McuSdkElfSymbolUploader(Uploader):
     def can_upload_file(self) -> bool:
         with open(self.file_path, "rb") as file:
             if file.read(4) != b"\x7FELF":
-                LOG.info("%s: Not an ELF file", self.file_path)
+                log.info("%s: Not an ELF file", self.file_path)
                 return False
             file.seek(0)
 
             inspector = BuildIdInspectorAndPatcher(file)
             if not elf_has_debug_info(inspector.elf):
-                LOG.info("%s: looks like an ELF but it has no .debug_info", self.file_path)
+                log.info("%s: looks like an ELF but it has no .debug_info", self.file_path)
                 return False
 
             mcu_build_id_type, mcu_build_id, mcu_build_id_short_len = inspector.get_build_info()
@@ -424,14 +422,14 @@ class McuSdkElfSymbolUploader(Uploader):
             # NB: QC symbol files have different arg requirements depending on the subsystem the
             # ELF is associated with so we offload to the Memfault backend.
             if not self.ctx.software_info and mcu_build_id is None and not self.qcomm_project:
-                LOG.error(
+                log.error(
                     "%s: Build Id missing. Specify --software-version and --software-type options "
                     "or add a Build Id (see https://mflt.io/symbol-file-build-ids)",
                     self.file_path,
                 )
                 return False
 
-        LOG.info("%s: ELF file with .debug_info. Build Id: %s", self.file_path, mcu_build_id)
+        log.info("%s: ELF file with .debug_info. Build Id: %s", self.file_path, mcu_build_id)
         return True
 
     def _is_already_uploaded(self) -> bool:
@@ -561,7 +559,7 @@ class ParallelUploader(Uploader):
                 queued_uploaders.append(uploader)
                 did_upload |= True
             else:
-                LOG.info("%s: skipping...", file_path)
+                log.info("%s: skipping...", file_path)
 
         def do_upload(uploader: Uploader):
             uploader.upload(progressbar=False)
@@ -629,7 +627,7 @@ class AndroidAppSymbolsUploader(Uploader):
 
     def can_upload_file(self) -> bool:
         if not os.path.isdir(self.file_path):
-            LOG.error(
+            log.error(
                 '%s is not a directory. Please specify the Android app\'s root "build" path instead!',
                 self.file_path,
             )
@@ -672,7 +670,7 @@ class AndroidAppSymbolsUploader(Uploader):
         for path in paths_to_check:
             if os.path.isfile(path):
                 return path
-        LOG.info("No mapping.txt found in default locations, assuming ProGuard/R8 is disabled...")
+        log.info("No mapping.txt found in default locations, assuming ProGuard/R8 is disabled...")
         return None
 
     def _upload_mapping_txt(self) -> bool:
